@@ -181,9 +181,9 @@ func newBucketStatement(policy BucketPolicy, bucketName, prefix string) (stateme
 		}
 		if prefix != "" {
 			condKeyMap := make(ConditionKeyMap)
-			condKeyMap.Add("s3:prefix", set.CreateStringSet(prefix))
+			condKeyMap.Add("s3:prefix", set.CreateStringSet(prefix+"*"))
 			condMap := make(ConditionMap)
-			condMap.Add("StringEquals", condKeyMap)
+			condMap.Add("StringLike", condKeyMap)
 			statement.Conditions = condMap
 		}
 		statements = append(statements, statement)
@@ -511,6 +511,18 @@ func getBucketPolicy(statement Statement, prefix string) (commonFound, readOnly,
 						readOnly = true
 					}
 				}
+			} else if stringLikeValue, ok := statement.Conditions["StringLike"]; ok {
+				if s3PrefixValues, ok := stringLikeValue["s3:prefix"]; ok {
+					if s3PrefixValues.Contains(prefix + "*") {
+						readOnly = true
+					}
+				}
+			} else if stringNotLikeValue, ok := statement.Conditions["StringNotLike"]; ok {
+				if s3PrefixValues, ok := stringNotLikeValue["s3:prefix"]; ok {
+					if !s3PrefixValues.Contains(prefix + "*") {
+						readOnly = true
+					}
+				}
 			}
 		} else if prefix == "" && statement.Conditions == nil {
 			readOnly = true
